@@ -32,8 +32,8 @@
 #include <fcntl.h>
 
 #include <gtk/gtksignal.h>
-#include <parser.h>
-#include <xmlmemory.h>
+#include <gnome-xml/parser.h>
+#include <gnome-xml/xmlmemory.h>
 
 #include "gal/util/e-util.h"
 #include "gal/util/e-xml-utils.h"
