@@ -1,11 +1,27 @@
-/*
- * GtkComboBox: A customizable ComboBox.
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * gtk-combo-box.c - a customizable combobox
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
  * Authors:
  *   Miguel de Icaza (miguel@gnu.org)
  *   Adrian E Feiguin (feiguin@ifir.edu.ar)
  *   Paolo Molnaro (lupus@debian.org).
  *   Jon K Hellan (hellan@acm.org)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 #include <config.h>
@@ -21,6 +37,7 @@
 #include <gtk/gtktearoffmenuitem.h>
 #include <gdk/gdkkeysyms.h>
 #include "gtk-combo-box.h"
+#include "gal/util/e-util.h"
 
 static GtkHBoxClass *gtk_combo_box_parent_class;
 static int gtk_combo_toggle_pressed (GtkToggleButton *tbutton,
@@ -43,7 +60,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static gint gtk_combo_box_signals [LAST_SIGNAL] = { 0, };
+static guint gtk_combo_box_signals [LAST_SIGNAL] = { 0, };
 
 struct _GtkComboBoxPrivate {
 	GtkWidget *pop_down_widget;
@@ -111,7 +128,7 @@ gtk_combo_box_class_init (GtkObjectClass *object_class)
 	gtk_combo_box_signals [POP_DOWN_WIDGET] = gtk_signal_new (
 		"pop_down_widget",
 		GTK_RUN_LAST,
-		object_class->type,
+		E_OBJECT_CLASS_TYPE (object_class),
 		GTK_SIGNAL_OFFSET (GtkComboBoxClass, pop_down_widget),
 		my_marshal_POINTER__NONE,
 		GTK_TYPE_POINTER, 0, GTK_TYPE_NONE);
@@ -119,7 +136,7 @@ gtk_combo_box_class_init (GtkObjectClass *object_class)
 	gtk_combo_box_signals [POP_DOWN_DONE] = gtk_signal_new (
 		"pop_down_done",
 		GTK_RUN_LAST,
-		object_class->type,
+		E_OBJECT_CLASS_TYPE (object_class),
 		GTK_SIGNAL_OFFSET (GtkComboBoxClass, pop_down_done),
 		gtk_marshal_BOOL__POINTER,
 		GTK_TYPE_BOOL, 1, GTK_TYPE_OBJECT);
@@ -127,7 +144,7 @@ gtk_combo_box_class_init (GtkObjectClass *object_class)
 	gtk_combo_box_signals [PRE_POP_DOWN] = gtk_signal_new (
 		"pre_pop_down",
 		GTK_RUN_LAST,
-		object_class->type,
+		E_OBJECT_CLASS_TYPE (object_class),
 		GTK_SIGNAL_OFFSET (GtkComboBoxClass, pre_pop_down),
 		gtk_marshal_NONE__NONE,
 		GTK_TYPE_NONE, 0);
@@ -135,12 +152,12 @@ gtk_combo_box_class_init (GtkObjectClass *object_class)
 	gtk_combo_box_signals [POST_POP_HIDE] = gtk_signal_new (
 		"post_pop_hide",
 		GTK_RUN_LAST,
-		object_class->type,
+		E_OBJECT_CLASS_TYPE (object_class),
 		GTK_SIGNAL_OFFSET (GtkComboBoxClass, post_pop_hide),
 		gtk_marshal_NONE__NONE,
 		GTK_TYPE_NONE, 0);
 	
-	gtk_object_class_add_signals (object_class, gtk_combo_box_signals, LAST_SIGNAL);
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, gtk_combo_box_signals, LAST_SIGNAL);
 }
 
 static void
